#
# spec file for package falkon
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Mariusz Fik <fisiu@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           falkon
Version:        3.0.1
Release:        lp152.3.13
Summary:        Modern web browser
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Browsers
Url:            https://www.falkon.org/
Source:         %{name}-%{version}.tar.xz
# Used to get a timestamp to override __DATE__ and __TIME__ with
Source1:        %{name}.changes
# Search engine favicons.
Source2:        obs.png
Source3:        opensusesoftware.png
BuildRequires:  cmake(KF5Wallet) >= 5.27.0
BuildRequires:  cmake(Qt5Concurrent) >= 5.9.0
BuildRequires:  cmake(Qt5Core) >= 5.9.0
BuildRequires:  cmake(Qt5DBus) >= 5.9.0
BuildRequires:  cmake(Qt5Gui) >= 5.9.0
BuildRequires:  cmake(Qt5Network) >= 5.9.0
BuildRequires:  cmake(Qt5Positioning) >= 5.9.0
BuildRequires:  cmake(Qt5PrintSupport) >= 5.9.0
BuildRequires:  cmake(Qt5Qml) >= 5.9.0
BuildRequires:  cmake(Qt5Quick) >= 5.9.0
BuildRequires:  cmake(Qt5QuickWidgets) >= 5.9.0
BuildRequires:  cmake(Qt5Script) >= 5.9.0
BuildRequires:  cmake(Qt5Sql) >= 5.9.0
BuildRequires:  cmake(Qt5Test) >= 5.9.0
BuildRequires:  cmake(Qt5WebChannel) >= 5.9.0
BuildRequires:  cmake(Qt5WebEngineCore) >= 5.9.0
BuildRequires:  cmake(Qt5WebEngineWidgets) >= 5.9.0
BuildRequires:  cmake(Qt5Widgets) >= 5.9.0
BuildRequires:  cmake(Qt5X11Extras) >= 5.9.0
BuildRequires:  extra-cmake-modules >= 5.27.0
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  ki18n-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  libressl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(xcb-atom)
BuildRequires:  update-desktop-files
Recommends:     %{name}-lang
# it doesn't start without it (boo#1067547)
Requires:       libQt5Sql5-sqlite
Provides:       qupzilla = %{version}
Obsoletes:      qupzilla < %{version}

%lang_package

%description
Falkon is a web browser designed to well integrate with all
common Linux desktops like GNOME and KDE Plasma desktops.
It supports current web standards and comes with many features,
such as an integrated ad blocker.

It was previously known as QupZilla.

%package gnome-keyring
Summary:        GNOME Keyring plugin for Falkon
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:gnome-keyring)
Provides:       qupzilla-gnome-keyring = %{version}
Obsoletes:      qupzilla-gnome-keyring < %{version}

%description gnome-keyring
Plugin for the Falkon browser that allows storing passwords in
GNOME Keyring.

%package kwallet
Summary:        KWallet plugin for Falkon
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Requires:       kwalletd5
Supplements:    packageand(%{name}:kwalletd5)
Provides:       qupzilla-kwallet = %{version}
Obsoletes:      qupzilla-kwallet < %{version}

%description kwallet
Plugin for the Falkon browser that allows storing passwords in KWallet.

%prep
%setup -q -n %{name}-%{version}
# Remove __DATE__ and __TIME__
FAKE_DATE="\"$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')\""
FAKE_TIME="\"$(LC_ALL=C date -u -r %{SOURCE1} '+%%H:%%M')\""
find .  -type f -regex '.*\.\(h\|c\|cpp\)' | xargs sed -i "s/__DATE__/${FAKE_DATE}/g;s/__TIME__/${FAKE_TIME}/g"

# openSUSE icons.
cp -f %{SOURCE2} %{SOURCE3} src/lib/data/icons/sites/

%build
  export USE_WEBGL=true
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall DESTDIR=%{buildroot} -C build
# FIXME: Split library into a separate package and also create falkon-devel with libfalkon.so ???
rm -vf %{buildroot}%{_libdir}/libFalkonPrivate.so
# We don't need a test plugin that does nothing.
rm -vf %{buildroot}%{_libdir}/%{name}/libTestPlugin.so

%suse_update_desktop_file org.kde.falkon
%fdupes %{buildroot}%{_kf5_sharedir}/

%find_lang %{name} --all-name --with-qt

%post
%desktop_database_post
%icon_theme_cache_post
/sbin/ldconfig

%postun
%desktop_database_postun
%icon_theme_cache_postun
/sbin/ldconfig

%files
%doc CHANGELOG COPYING README.md
%exclude %{_kf5_plugindir}/falkon/GnomeKeyringPasswords.so
%exclude %{_kf5_plugindir}/falkon/KWalletPasswords.so
%{_kf5_appstreamdir}/org.kde.falkon.appdata.xml
%{_kf5_bindir}/falkon
%{_kf5_libdir}/libFalkonPrivate.so.*
%{_kf5_plugindir}/falkon/
%{_kf5_sharedir}/applications/org.kde.falkon.desktop
%{_kf5_sharedir}/bash-completion/
%{_kf5_sharedir}/falkon/
%{_kf5_sharedir}/icons/hicolor/*/apps/falkon.*
%{_kf5_sharedir}/pixmaps/falkon.png

%files gnome-keyring
%{_kf5_plugindir}/falkon/GnomeKeyringPasswords.so

%files kwallet
%{_kf5_plugindir}/falkon/KWalletPasswords.so

%files lang -f %{name}.lang

%changelog
* Wed May  9 2018 kamikazow@opensuse.org
- Update 3.0.1
  * added profile migration from QupZilla
  * fix incorrectly completing form data on some sites #391327
  * fix showing incorrect state of back and forward buttons #391331
  * fix loading urls containing %%20 from location bar #392445
  * fix save page action for downloading text files #391300
  * fix download manager trying to closing not restored tabs #392565
  * fix updating location bar site icon after using paste and go action #392747
  * fix various issues with QtWebEngine 5.11 #392885, #393398
  * fix speed dial sometimes loading with no pages #391875
  * fix leaving html fullscreen after closing tab #393797
  * fix saving speed dial settings when there are no configured pages
  * fix restoring nested crashed sessions
  * fix setting minimum height of bookmarks toolbar
  * VerticalTabs: fix preserving expanded state of times inside collapsed parent #393567
  * VerticalTabs: don’t force open sidebar when opening new window #393629
- Remove falkon-defaults.patch because the speeddial and bookmarks bar handling
  has been completely rewritten and must be totally reworked (to do).
* Sat Apr 21 2018 kamikazow@opensuse.org
- Minor housekeeping
  * Change qupzilla.com URLs to falkon.org
  * Make the package description a bit more informative w/o using jargon
  * Clean up specfile from leftover stuff from older versions
* Tue Apr 10 2018 wbauer@tmo.at
- Require libQt5Sql5-sqlite, without it Falkon doesn't even start
  (boo#1067547)
* Sat Mar 10 2018 kamikazow@opensuse.org
- Minimum Qt version is 5.9 according to Falkon's CMakeLists.txt
* Tue Feb 27 2018 wbauer@tmo.at
- Version 3.0.0
  * released 27 February 2018
  * first Falkon release
  * added experimental support for Python extensions
* Tue Aug 29 2017 kamikazow@opensuse.org
- Small typo fix (Kwallet -> KWallet)
* Sat Aug 26 2017 fabian@ritter-vogt.de
- Initial packaging, copied from qupzilla package
